# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.oauth import claims_pb2 as yandex_dot_cloud_dot_oauth_dot_claims__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/user_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1fyandex/cloud/oauth/claims.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"z\n\x12ListMembersRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\xd7\x01\n\x13ListMembersResponse\x12X\n\x05users\x18\x01 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.ListMembersResponse.OrganizationUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1aM\n\x10OrganizationUser\x12\x39\n\x0esubject_claims\x18\x01 \x01(\x0b\x32!.yandex.cloud.oauth.SubjectClaims\"^\n\x17\x44\x65leteMembershipRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nsubject_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"c\n\x18\x44\x65leteMembershipMetadata\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"c\n\x18\x44\x65leteMembershipResponse\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xdc\x03\n\x0bUserService\x12\xc8\x01\n\x0bListMembers\x12\x37.yandex.cloud.organizationmanager.v1.ListMembersRequest\x1a\x38.yandex.cloud.organizationmanager.v1.ListMembersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/organization-manager/v1/organizations/{organization_id}/users\x12\x81\x02\n\x10\x44\x65leteMembership\x12<.yandex.cloud.organizationmanager.v1.DeleteMembershipRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*4\n\x18\x44\x65leteMembershipMetadata\x12\x18\x44\x65leteMembershipResponse\x82\xd3\xe4\x93\x02M*K/organization-manager/v1/organizations/{organization_id}/users/{subject_id}B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['subject_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['subject_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_USERSERVICE'].methods_by_name['ListMembers']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ListMembers']._serialized_options = b'\202\323\344\223\002@\022>/organization-manager/v1/organizations/{organization_id}/users'
  _globals['_USERSERVICE'].methods_by_name['DeleteMembership']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['DeleteMembership']._serialized_options = b'\262\322*4\n\030DeleteMembershipMetadata\022\030DeleteMembershipResponse\202\323\344\223\002M*K/organization-manager/v1/organizations/{organization_id}/users/{subject_id}'
  _globals['_LISTMEMBERSREQUEST']._serialized_start=263
  _globals['_LISTMEMBERSREQUEST']._serialized_end=385
  _globals['_LISTMEMBERSRESPONSE']._serialized_start=388
  _globals['_LISTMEMBERSRESPONSE']._serialized_end=603
  _globals['_LISTMEMBERSRESPONSE_ORGANIZATIONUSER']._serialized_start=526
  _globals['_LISTMEMBERSRESPONSE_ORGANIZATIONUSER']._serialized_end=603
  _globals['_DELETEMEMBERSHIPREQUEST']._serialized_start=605
  _globals['_DELETEMEMBERSHIPREQUEST']._serialized_end=699
  _globals['_DELETEMEMBERSHIPMETADATA']._serialized_start=701
  _globals['_DELETEMEMBERSHIPMETADATA']._serialized_end=800
  _globals['_DELETEMEMBERSHIPRESPONSE']._serialized_start=802
  _globals['_DELETEMEMBERSHIPRESPONSE']._serialized_end=901
  _globals['_USERSERVICE']._serialized_start=904
  _globals['_USERSERVICE']._serialized_end=1380
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/private_subnet_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/private_subnet_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import private_subnet_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_private__subnet__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/baremetal/v1alpha/private_subnet_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x33yandex/cloud/baremetal/v1alpha/private_subnet.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"T\n\x17GetPrivateSubnetRequest\x12\x33\n\x11private_subnet_id\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30J\x04\x08\x01\x10\x02\"\xa5\x01\n\x18ListPrivateSubnetRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"\x88\x01\n\x19ListPrivateSubnetResponse\x12\x46\n\x0fprivate_subnets\x18\x02 \x03(\x0b\x32-.yandex.cloud.baremetal.v1alpha.PrivateSubnet\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x64\"\xdf\x03\n\x1a\x43reatePrivateSubnetRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\"\n\x10hardware_pool_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=20\x12H\n\x10vrf_options_spec\x18\x04 \x01(\x0b\x32..yandex.cloud.baremetal.v1alpha.VrfOptionsSpec\x12/\n\tfolder_id\x18\x05 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x94\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x46.yandex.cloud.baremetal.v1alpha.CreatePrivateSubnetRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x06\x10\xc8\x01\"\x89\x01\n\x0eVrfOptionsSpec\x12\x0e\n\x06vrf_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63idr\x18\x02 \x01(\t\x12\x45\n\x0c\x64hcp_options\x18\x03 \x01(\x0b\x32/.yandex.cloud.baremetal.v1alpha.DhcpOptionsSpec\x12\x12\n\ngateway_ip\x18\x04 \x01(\t\"3\n\x0f\x44hcpOptionsSpec\x12\x10\n\x08start_ip\x18\x01 \x01(\t\x12\x0e\n\x06\x65nd_ip\x18\x02 \x01(\t\">\n\x1b\x43reatePrivateSubnetMetadata\x12\x19\n\x11private_subnet_id\x18\x02 \x01(\tJ\x04\x08\x01\x10\x02\"\xf0\x03\n\x1aUpdatePrivateSubnetRequest\x12\x33\n\x11private_subnet_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12H\n\x10vrf_options_spec\x18\x05 \x01(\x0b\x32..yandex.cloud.baremetal.v1alpha.VrfOptionsSpec\x12\x94\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x46.yandex.cloud.baremetal.v1alpha.UpdatePrivateSubnetRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x06\x10\xc8\x01\">\n\x1bUpdatePrivateSubnetMetadata\x12\x19\n\x11private_subnet_id\x18\x02 \x01(\tJ\x04\x08\x01\x10\x02\"W\n\x1a\x44\x65letePrivateSubnetRequest\x12\x33\n\x11private_subnet_id\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30J\x04\x08\x01\x10\x02\">\n\x1b\x44\x65letePrivateSubnetMetadata\x12\x19\n\x11private_subnet_id\x18\x02 \x01(\tJ\x04\x08\x01\x10\x02\"\x97\x01\n\"ListPrivateSubnetOperationsRequest\x12\x33\n\x11private_subnet_id\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x64\"{\n#ListPrivateSubnetOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xd9\t\n\x14PrivateSubnetService\x12\xac\x01\n\x03Get\x12\x37.yandex.cloud.baremetal.v1alpha.GetPrivateSubnetRequest\x1a-.yandex.cloud.baremetal.v1alpha.PrivateSubnet\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/baremetal/v1alpha/privateSubnets/{private_subnet_id}\x12\xa6\x01\n\x04List\x12\x38.yandex.cloud.baremetal.v1alpha.ListPrivateSubnetRequest\x1a\x39.yandex.cloud.baremetal.v1alpha.ListPrivateSubnetResponse\")\x82\xd3\xe4\x93\x02#\x12!/baremetal/v1alpha/privateSubnets\x12\xc5\x01\n\x06\x43reate\x12:.yandex.cloud.baremetal.v1alpha.CreatePrivateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*,\n\x1b\x43reatePrivateSubnetMetadata\x12\rPrivateSubnet\x82\xd3\xe4\x93\x02&\"!/baremetal/v1alpha/privateSubnets:\x01*\x12\xd9\x01\n\x06Update\x12:.yandex.cloud.baremetal.v1alpha.UpdatePrivateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*,\n\x1bUpdatePrivateSubnetMetadata\x12\rPrivateSubnet\x82\xd3\xe4\x93\x02:25/baremetal/v1alpha/privateSubnets/{private_subnet_id}:\x01*\x12\xde\x01\n\x06\x44\x65lete\x12:.yandex.cloud.baremetal.v1alpha.DeletePrivateSubnetRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*4\n\x1b\x44\x65letePrivateSubnetMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x37*5/baremetal/v1alpha/privateSubnets/{private_subnet_id}\x12\xe3\x01\n\x0eListOperations\x12\x42.yandex.cloud.baremetal.v1alpha.ListPrivateSubnetOperationsRequest\x1a\x43.yandex.cloud.baremetal.v1alpha.ListPrivateSubnetOperationsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/baremetal/v1alpha/privateSubnets/{private_subnet_id}/operationsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.private_subnet_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETPRIVATESUBNETREQUEST'].fields_by_name['private_subnet_id']._loaded_options = None
  _globals['_GETPRIVATESUBNETREQUEST'].fields_by_name['private_subnet_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTPRIVATESUBNETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTPRIVATESUBNETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTPRIVATESUBNETREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPRIVATESUBNETREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_CREATEPRIVATESUBNETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEPRIVATESUBNETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['hardware_pool_id']._loaded_options = None
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['hardware_pool_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEPRIVATESUBNETREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEPRIVATESUBNETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPRIVATESUBNETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['private_subnet_id']._loaded_options = None
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['private_subnet_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEPRIVATESUBNETREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEPRIVATESUBNETREQUEST'].fields_by_name['private_subnet_id']._loaded_options = None
  _globals['_DELETEPRIVATESUBNETREQUEST'].fields_by_name['private_subnet_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTPRIVATESUBNETOPERATIONSREQUEST'].fields_by_name['private_subnet_id']._loaded_options = None
  _globals['_LISTPRIVATESUBNETOPERATIONSREQUEST'].fields_by_name['private_subnet_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTPRIVATESUBNETOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPRIVATESUBNETOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0027\0225/baremetal/v1alpha/privateSubnets/{private_subnet_id}'
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/baremetal/v1alpha/privateSubnets'
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*,\n\033CreatePrivateSubnetMetadata\022\rPrivateSubnet\202\323\344\223\002&\"!/baremetal/v1alpha/privateSubnets:\001*'
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*,\n\033UpdatePrivateSubnetMetadata\022\rPrivateSubnet\202\323\344\223\002:25/baremetal/v1alpha/privateSubnets/{private_subnet_id}:\001*'
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*4\n\033DeletePrivateSubnetMetadata\022\025google.protobuf.Empty\202\323\344\223\0027*5/baremetal/v1alpha/privateSubnets/{private_subnet_id}'
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_PRIVATESUBNETSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002B\022@/baremetal/v1alpha/privateSubnets/{private_subnet_id}/operations'
  _globals['_GETPRIVATESUBNETREQUEST']._serialized_start=317
  _globals['_GETPRIVATESUBNETREQUEST']._serialized_end=401
  _globals['_LISTPRIVATESUBNETREQUEST']._serialized_start=404
  _globals['_LISTPRIVATESUBNETREQUEST']._serialized_end=569
  _globals['_LISTPRIVATESUBNETRESPONSE']._serialized_start=572
  _globals['_LISTPRIVATESUBNETRESPONSE']._serialized_end=708
  _globals['_CREATEPRIVATESUBNETREQUEST']._serialized_start=711
  _globals['_CREATEPRIVATESUBNETREQUEST']._serialized_end=1190
  _globals['_CREATEPRIVATESUBNETREQUEST_LABELSENTRY']._serialized_start=1138
  _globals['_CREATEPRIVATESUBNETREQUEST_LABELSENTRY']._serialized_end=1183
  _globals['_VRFOPTIONSSPEC']._serialized_start=1193
  _globals['_VRFOPTIONSSPEC']._serialized_end=1330
  _globals['_DHCPOPTIONSSPEC']._serialized_start=1332
  _globals['_DHCPOPTIONSSPEC']._serialized_end=1383
  _globals['_CREATEPRIVATESUBNETMETADATA']._serialized_start=1385
  _globals['_CREATEPRIVATESUBNETMETADATA']._serialized_end=1447
  _globals['_UPDATEPRIVATESUBNETREQUEST']._serialized_start=1450
  _globals['_UPDATEPRIVATESUBNETREQUEST']._serialized_end=1946
  _globals['_UPDATEPRIVATESUBNETREQUEST_LABELSENTRY']._serialized_start=1138
  _globals['_UPDATEPRIVATESUBNETREQUEST_LABELSENTRY']._serialized_end=1183
  _globals['_UPDATEPRIVATESUBNETMETADATA']._serialized_start=1948
  _globals['_UPDATEPRIVATESUBNETMETADATA']._serialized_end=2010
  _globals['_DELETEPRIVATESUBNETREQUEST']._serialized_start=2012
  _globals['_DELETEPRIVATESUBNETREQUEST']._serialized_end=2099
  _globals['_DELETEPRIVATESUBNETMETADATA']._serialized_start=2101
  _globals['_DELETEPRIVATESUBNETMETADATA']._serialized_end=2163
  _globals['_LISTPRIVATESUBNETOPERATIONSREQUEST']._serialized_start=2166
  _globals['_LISTPRIVATESUBNETOPERATIONSREQUEST']._serialized_end=2317
  _globals['_LISTPRIVATESUBNETOPERATIONSRESPONSE']._serialized_start=2319
  _globals['_LISTPRIVATESUBNETOPERATIONSRESPONSE']._serialized_end=2442
  _globals['_PRIVATESUBNETSERVICE']._serialized_start=2445
  _globals['_PRIVATESUBNETSERVICE']._serialized_end=3686
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Link(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Dashboard(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class ParametersEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

        PROJECT_ID_FIELD_NUMBER: builtins.int
        FOLDER_ID_FIELD_NUMBER: builtins.int
        DASHBOARD_NAME_FIELD_NUMBER: builtins.int
        APPLY_TIME_RANGE_FIELD_NUMBER: builtins.int
        PARAMETERS_FIELD_NUMBER: builtins.int
        project_id: builtins.str
        folder_id: builtins.str
        dashboard_name: builtins.str
        apply_time_range: builtins.bool
        @property
        def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """What parameter values to pass to dashboard when opening link
            See Parametrization field in dashboard.proto
            """

        def __init__(
            self,
            *,
            project_id: builtins.str = ...,
            folder_id: builtins.str = ...,
            dashboard_name: builtins.str = ...,
            apply_time_range: builtins.bool = ...,
            parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id", "project_id", b"project_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["apply_time_range", b"apply_time_range", "container", b"container", "dashboard_name", b"dashboard_name", "folder_id", b"folder_id", "parameters", b"parameters", "project_id", b"project_id"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["project_id", "folder_id"] | None: ...

    TITLE_FIELD_NUMBER: builtins.int
    OPEN_IN_NEW_TAB_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DASHBOARD_FIELD_NUMBER: builtins.int
    title: builtins.str
    """Required. Link title."""
    open_in_new_tab: builtins.bool
    """Open link in new tab."""
    url: builtins.str
    """Url that can be a template with mustache expressions ({{expression}})
    Variables available for template:
    - Dashboard time interval in diverse formats. Variables: __from:<format>, __to:<format>,
      where format is one of: iso, seconds or milliseconds.
    - Dashboard parameters
    """
    @property
    def dashboard(self) -> global___Link.Dashboard: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        open_in_new_tab: builtins.bool = ...,
        url: builtins.str = ...,
        dashboard: global___Link.Dashboard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dashboard", b"dashboard", "type", b"type", "url", b"url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dashboard", b"dashboard", "open_in_new_tab", b"open_in_new_tab", "title", b"title", "type", b"type", "url", b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["url", "dashboard"] | None: ...

global___Link = Link



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.episode_pb2
import yandex.cloud.video.v1.episode_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class EpisodeServiceStub:
    """Episode management service.
    Provides methods for creating, retrieving, updating, and deleting episodes,
    which represent specific time segments of streams
    that can be individually accessed, managed, and published.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeRequest,
        yandex.cloud.video.v1.episode_pb2.Episode,
    ]
    """Retrieves detailed information about a specific episode by its ID.
    Returns all episode metadata, status, and related information.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesRequest,
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse,
    ]
    """Lists all episodes associated with a specific stream or stream line with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    BatchGet: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesRequest,
        yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesResponse,
    ]
    """Retrieves multiple episodes by their IDs in a specific channel in a single request.
    This is more efficient than making multiple Get requests when retrieving several episodes.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.CreateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new episode associated with a stream or stream line.
    Episodes can be configured with various settings including title, description,
    time boundaries, and access rights.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.UpdateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing episode's metadata and settings.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.DeleteEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific episode by its ID."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.BatchDeleteEpisodesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes multiple episodes associated with a specific stream or stream line in a single request.
    This is more efficient than making multiple Delete requests when removing several episodes.
    """

    PerformAction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.PerformEpisodeActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs a specific action on an episode, such as publishing or unpublishing."""

    GetPlayerURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse,
    ]
    """Generates a player URL for watching the episode.
    The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
    For episodes with signed URL access, an expiration duration can be specified.
    """

    GetManifests: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse,
    ]
    """Retrieves the manifest URLs for the episode's media content.
    Manifests provide players with necessary information
    for streaming the content with different quality levels and formats.
    """

class EpisodeServiceAsyncStub:
    """Episode management service.
    Provides methods for creating, retrieving, updating, and deleting episodes,
    which represent specific time segments of streams
    that can be individually accessed, managed, and published.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeRequest,
        yandex.cloud.video.v1.episode_pb2.Episode,
    ]
    """Retrieves detailed information about a specific episode by its ID.
    Returns all episode metadata, status, and related information.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesRequest,
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse,
    ]
    """Lists all episodes associated with a specific stream or stream line with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    BatchGet: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesRequest,
        yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesResponse,
    ]
    """Retrieves multiple episodes by their IDs in a specific channel in a single request.
    This is more efficient than making multiple Get requests when retrieving several episodes.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.CreateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new episode associated with a stream or stream line.
    Episodes can be configured with various settings including title, description,
    time boundaries, and access rights.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.UpdateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an existing episode's metadata and settings.
    Only fields specified in the field_mask will be updated.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.DeleteEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific episode by its ID."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.BatchDeleteEpisodesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes multiple episodes associated with a specific stream or stream line in a single request.
    This is more efficient than making multiple Delete requests when removing several episodes.
    """

    PerformAction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.PerformEpisodeActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Performs a specific action on an episode, such as publishing or unpublishing."""

    GetPlayerURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse,
    ]
    """Generates a player URL for watching the episode.
    The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
    For episodes with signed URL access, an expiration duration can be specified.
    """

    GetManifests: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse,
    ]
    """Retrieves the manifest URLs for the episode's media content.
    Manifests provide players with necessary information
    for streaming the content with different quality levels and formats.
    """

class EpisodeServiceServicer(metaclass=abc.ABCMeta):
    """Episode management service.
    Provides methods for creating, retrieving, updating, and deleting episodes,
    which represent specific time segments of streams
    that can be individually accessed, managed, and published.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.GetEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_pb2.Episode, collections.abc.Awaitable[yandex.cloud.video.v1.episode_pb2.Episode]]:
        """Retrieves detailed information about a specific episode by its ID.
        Returns all episode metadata, status, and related information.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.ListEpisodesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse]]:
        """Lists all episodes associated with a specific stream or stream line with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """

    @abc.abstractmethod
    def BatchGet(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.BatchGetEpisodesResponse]]:
        """Retrieves multiple episodes by their IDs in a specific channel in a single request.
        This is more efficient than making multiple Get requests when retrieving several episodes.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.CreateEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new episode associated with a stream or stream line.
        Episodes can be configured with various settings including title, description,
        time boundaries, and access rights.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.UpdateEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an existing episode's metadata and settings.
        Only fields specified in the field_mask will be updated.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.DeleteEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a specific episode by its ID."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.BatchDeleteEpisodesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes multiple episodes associated with a specific stream or stream line in a single request.
        This is more efficient than making multiple Delete requests when removing several episodes.
        """

    @abc.abstractmethod
    def PerformAction(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.PerformEpisodeActionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Performs a specific action on an episode, such as publishing or unpublishing."""

    @abc.abstractmethod
    def GetPlayerURL(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse]]:
        """Generates a player URL for watching the episode.
        The URL can include player parameters such as autoplay, mute, and visibility of interface controls.
        For episodes with signed URL access, an expiration duration can be specified.
        """

    @abc.abstractmethod
    def GetManifests(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse]]:
        """Retrieves the manifest URLs for the episode's media content.
        Manifests provide players with necessary information
        for streaming the content with different quality levels and formats.
        """

def add_EpisodeServiceServicer_to_server(servicer: EpisodeServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.subtitle_pb2
import yandex.cloud.video.v1.subtitle_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SubtitleServiceStub:
    """Subtitle management service.
    Provides methods for creating, retrieving, updating, and deleting subtitles,
    which provide text translations or transcriptions of video content in various languages.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GetSubtitleRequest,
        yandex.cloud.video.v1.subtitle_pb2.Subtitle,
    ]
    """Retrieves detailed information about a specific subtitle by its ID.
    Returns all subtitle metadata and related information.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse,
    ]
    """Lists all subtitles associated with a specific video with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.CreateSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new subtitle record for a specific video.
    This method only creates the metadata record; the actual subtitle file must be uploaded
    using the URL obtained from the GenerateUploadURL method.
    """

    GenerateUploadURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse,
    ]
    """Generates a URL for uploading a subtitle file to an existing subtitle record.
    This URL can be used to upload the actual subtitle file using an HTTP PUT request.
    The URL is pre-signed and has a limited validity period.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.DeleteSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific subtitle by its ID.
    This removes both the metadata record and the associated subtitle file.
    """

class SubtitleServiceAsyncStub:
    """Subtitle management service.
    Provides methods for creating, retrieving, updating, and deleting subtitles,
    which provide text translations or transcriptions of video content in various languages.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GetSubtitleRequest,
        yandex.cloud.video.v1.subtitle_pb2.Subtitle,
    ]
    """Retrieves detailed information about a specific subtitle by its ID.
    Returns all subtitle metadata and related information.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse,
    ]
    """Lists all subtitles associated with a specific video with pagination support.
    Results can be filtered and sorted using the provided parameters.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.CreateSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new subtitle record for a specific video.
    This method only creates the metadata record; the actual subtitle file must be uploaded
    using the URL obtained from the GenerateUploadURL method.
    """

    GenerateUploadURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLRequest,
        yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse,
    ]
    """Generates a URL for uploading a subtitle file to an existing subtitle record.
    This URL can be used to upload the actual subtitle file using an HTTP PUT request.
    The URL is pre-signed and has a limited validity period.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.subtitle_service_pb2.DeleteSubtitleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a specific subtitle by its ID.
    This removes both the metadata record and the associated subtitle file.
    """

class SubtitleServiceServicer(metaclass=abc.ABCMeta):
    """Subtitle management service.
    Provides methods for creating, retrieving, updating, and deleting subtitles,
    which provide text translations or transcriptions of video content in various languages.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.GetSubtitleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.subtitle_pb2.Subtitle, collections.abc.Awaitable[yandex.cloud.video.v1.subtitle_pb2.Subtitle]]:
        """Retrieves detailed information about a specific subtitle by its ID.
        Returns all subtitle metadata and related information.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.subtitle_service_pb2.ListSubtitlesResponse]]:
        """Lists all subtitles associated with a specific video with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.CreateSubtitleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new subtitle record for a specific video.
        This method only creates the metadata record; the actual subtitle file must be uploaded
        using the URL obtained from the GenerateUploadURL method.
        """

    @abc.abstractmethod
    def GenerateUploadURL(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.subtitle_service_pb2.GenerateSubtitleUploadURLResponse]]:
        """Generates a URL for uploading a subtitle file to an existing subtitle record.
        This URL can be used to upload the actual subtitle file using an HTTP PUT request.
        The URL is pre-signed and has a limited validity period.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.subtitle_service_pb2.DeleteSubtitleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a specific subtitle by its ID.
        This removes both the metadata record and the associated subtitle file.
        """

def add_SubtitleServiceServicer_to_server(servicer: SubtitleServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.disk_type_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDiskTypeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    disk_type_id: builtins.str
    """ID of the disk type to return information about.
    To get the disk type ID use a [DiskTypeService.List] request.
    """
    def __init__(
        self,
        *,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_type_id", b"disk_type_id"]) -> None: ...

global___GetDiskTypeRequest = GetDiskTypeRequest

@typing.final
class ListDiskTypesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDiskTypesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDiskTypesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDiskTypesRequest = ListDiskTypesRequest

@typing.final
class ListDiskTypesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_TYPES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDiskTypesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDiskTypesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def disk_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.disk_type_pb2.DiskType]:
        """List of disk types."""

    def __init__(
        self,
        *,
        disk_types: collections.abc.Iterable[yandex.cloud.compute.v1.disk_type_pb2.DiskType] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_types", b"disk_types", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDiskTypesResponse = ListDiskTypesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/dataset/v1/dataset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/dataset/v1/dataset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.ai.dataset.v1 import dataset_pb2 as yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/ai/dataset/v1/dataset_service.proto\x12\x1ayandex.cloud.ai.dataset.v1\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a(yandex/cloud/ai/dataset/v1/dataset.proto\x1a google/protobuf/field_mask.proto\"2\n\x16\x44\x65scribeDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"S\n\x17\x44\x65scribeDatasetResponse\x12\x38\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\"2\n\x16ValidateDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"m\n\x17ValidateDatasetMetadata\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nvalid_rows\x18\x02 \x01(\x03\x12\x16\n\x0eprocessed_rows\x18\x03 \x01(\x03\x12\x12\n\ntotal_rows\x18\x04 \x01(\x03\"|\n\x17ValidateDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x10\n\x08is_valid\x18\x02 \x01(\x08\x12;\n\x06\x65rrors\x18\x03 \x03(\x0b\x32+.yandex.cloud.ai.dataset.v1.ValidationError\"0\n\x14\x44\x65leteDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x17\n\x15\x44\x65leteDatasetResponse\"\xd5\x02\n\x14\x43reateDatasetRequest\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\x1f\n\ttask_type\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.ai.dataset.v1.CreateDatasetRequest.LabelsEntry\x12#\n\rupload_format\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0e\x61llow_data_log\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x15\x43reateDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x38\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\"\x81\x02\n\x14UpdateDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12L\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.ai.dataset.v1.UpdateDatasetRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x15UpdateDatasetResponse\x12\x38\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\"P\n\x18GetUploadDraftUrlRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nsize_bytes\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"C\n\x19GetUploadDraftUrlResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nupload_url\x18\x02 \x01(\t\"g\n StartMultipartUploadDraftRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nsize_bytes\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\r\n\x05parts\x18\x03 \x01(\x03\"V\n!StartMultipartUploadDraftResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x1d\n\x15multipart_upload_urls\x18\x02 \x03(\t\"E\n\x10UploadedPartInfo\x12\x1d\n\x08part_num\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-10000\x12\x12\n\x04\x65tag\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\x83\x01\n!FinishMultipartUploadDraftRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x44\n\x0euploaded_parts\x18\x02 \x03(\x0b\x32,.yandex.cloud.ai.dataset.v1.UploadedPartInfo\"8\n\"FinishMultipartUploadDraftResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\"\xe2\x01\n\x13ListDatasetsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12>\n\x06status\x18\x02 \x03(\x0e\x32..yandex.cloud.ai.dataset.v1.DatasetInfo.Status\x12\x1c\n\x14\x64\x61taset_name_pattern\x18\x03 \x01(\t\x12\x18\n\x10task_type_filter\x18\x04 \x03(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x03\x12\x12\n\npage_token\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x61taset_ids\x18\x07 \x03(\t\"j\n\x14ListDatasetsResponse\x12\x39\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x18ListUploadFormatsRequest\x12\x17\n\ttask_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\",\n\x19ListUploadFormatsResponse\x12\x0f\n\x07\x66ormats\x18\x01 \x03(\t\"F\n\x18ListUploadSchemasRequest\x12\x17\n\ttask_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tfolder_id\x18\x02 \x01(\t\"]\n\x19ListUploadSchemasResponse\x12@\n\x07schemas\x18\x01 \x03(\x0b\x32/.yandex.cloud.ai.dataset.v1.DatasetUploadSchema\"%\n\x10ListTypesRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"\"\n\x11ListTypesResponse\x12\r\n\x05types\x18\x01 \x03(\t\"4\n\x18GetDatasetPreviewRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"F\n\x19GetDatasetPreviewResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x15\n\rpreview_lines\x18\x02 \x03(\t\"2\n\x16GetDownloadUrlsRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"x\n\x17GetDownloadUrlsResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12I\n\rdownload_urls\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.ai.dataset.v1.DatasetFileDownloadUrl\".\n\x18ListOperationsIdsRequest\x12\x12\n\ndataset_id\x18\x01 \x03(\t\"\xd1\x01\n\x19ListOperationsIdsResponse\x12u\n\x1a\x64\x61taset_id_to_operation_id\x18\x01 \x03(\x0b\x32Q.yandex.cloud.ai.dataset.v1.ListOperationsIdsResponse.DatasetIdToOperationIdEntry\x1a=\n\x1b\x44\x61tasetIdToOperationIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x84\x0f\n\x0e\x44\x61tasetService\x12s\n\x08\x44\x65scribe\x12\x32.yandex.cloud.ai.dataset.v1.DescribeDatasetRequest\x1a\x33.yandex.cloud.ai.dataset.v1.DescribeDatasetResponse\x12\x99\x01\n\x08Validate\x12\x32.yandex.cloud.ai.dataset.v1.ValidateDatasetRequest\x1a!.yandex.cloud.operation.Operation\"6\xb2\xd2*2\n\x17ValidateDatasetMetadata\x12\x17ValidateDatasetResponse\x12m\n\x06\x43reate\x12\x30.yandex.cloud.ai.dataset.v1.CreateDatasetRequest\x1a\x31.yandex.cloud.ai.dataset.v1.CreateDatasetResponse\x12m\n\x06Update\x12\x30.yandex.cloud.ai.dataset.v1.UpdateDatasetRequest\x1a\x31.yandex.cloud.ai.dataset.v1.UpdateDatasetResponse\x12m\n\x06\x44\x65lete\x12\x30.yandex.cloud.ai.dataset.v1.DeleteDatasetRequest\x1a\x31.yandex.cloud.ai.dataset.v1.DeleteDatasetResponse\x12i\n\x04List\x12/.yandex.cloud.ai.dataset.v1.ListDatasetsRequest\x1a\x30.yandex.cloud.ai.dataset.v1.ListDatasetsResponse\x12\x85\x01\n\x11ListUploadFormats\x12\x34.yandex.cloud.ai.dataset.v1.ListUploadFormatsRequest\x1a\x35.yandex.cloud.ai.dataset.v1.ListUploadFormatsResponse\"\x03\x88\x02\x01\x12\x80\x01\n\x11ListUploadSchemas\x12\x34.yandex.cloud.ai.dataset.v1.ListUploadSchemasRequest\x1a\x35.yandex.cloud.ai.dataset.v1.ListUploadSchemasResponse\x12\x80\x01\n\x11GetUploadDraftUrl\x12\x34.yandex.cloud.ai.dataset.v1.GetUploadDraftUrlRequest\x1a\x35.yandex.cloud.ai.dataset.v1.GetUploadDraftUrlResponse\x12z\n\x0fGetDownloadUrls\x12\x32.yandex.cloud.ai.dataset.v1.GetDownloadUrlsRequest\x1a\x33.yandex.cloud.ai.dataset.v1.GetDownloadUrlsResponse\x12\x98\x01\n\x19StartMultipartUploadDraft\x12<.yandex.cloud.ai.dataset.v1.StartMultipartUploadDraftRequest\x1a=.yandex.cloud.ai.dataset.v1.StartMultipartUploadDraftResponse\x12\x9b\x01\n\x1a\x46inishMultipartUploadDraft\x12=.yandex.cloud.ai.dataset.v1.FinishMultipartUploadDraftRequest\x1a>.yandex.cloud.ai.dataset.v1.FinishMultipartUploadDraftResponse\x12h\n\tListTypes\x12,.yandex.cloud.ai.dataset.v1.ListTypesRequest\x1a-.yandex.cloud.ai.dataset.v1.ListTypesResponse\x12y\n\nGetPreview\x12\x34.yandex.cloud.ai.dataset.v1.GetDatasetPreviewRequest\x1a\x35.yandex.cloud.ai.dataset.v1.GetDatasetPreviewResponse\x12\x80\x01\n\x11ListOperationsIds\x12\x34.yandex.cloud.ai.dataset.v1.ListOperationsIdsRequest\x1a\x35.yandex.cloud.ai.dataset.v1.ListOperationsIdsResponseBe\n\x1eyandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.dataset.v1.dataset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomo'
  _globals['_DESCRIBEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_DESCRIBEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_VALIDATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_VALIDATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_DELETEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['task_type']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['task_type']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['upload_format']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['upload_format']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['size_bytes']._loaded_options = None
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['size_bytes']._serialized_options = b'\372\3071\002>0'
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['size_bytes']._loaded_options = None
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['size_bytes']._serialized_options = b'\372\3071\002>0'
  _globals['_UPLOADEDPARTINFO'].fields_by_name['part_num']._loaded_options = None
  _globals['_UPLOADEDPARTINFO'].fields_by_name['part_num']._serialized_options = b'\372\3071\0071-10000'
  _globals['_UPLOADEDPARTINFO'].fields_by_name['etag']._loaded_options = None
  _globals['_UPLOADEDPARTINFO'].fields_by_name['etag']._serialized_options = b'\350\3071\001'
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTUPLOADFORMATSREQUEST'].fields_by_name['task_type']._loaded_options = None
  _globals['_LISTUPLOADFORMATSREQUEST'].fields_by_name['task_type']._serialized_options = b'\350\3071\001'
  _globals['_LISTUPLOADSCHEMASREQUEST'].fields_by_name['task_type']._loaded_options = None
  _globals['_LISTUPLOADSCHEMASREQUEST'].fields_by_name['task_type']._serialized_options = b'\350\3071\001'
  _globals['_GETDATASETPREVIEWREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_GETDATASETPREVIEWREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_GETDOWNLOADURLSREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_GETDOWNLOADURLSREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._loaded_options = None
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._serialized_options = b'8\001'
  _globals['_DATASETSERVICE'].methods_by_name['Validate']._loaded_options = None
  _globals['_DATASETSERVICE'].methods_by_name['Validate']._serialized_options = b'\262\322*2\n\027ValidateDatasetMetadata\022\027ValidateDatasetResponse'
  _globals['_DATASETSERVICE'].methods_by_name['ListUploadFormats']._loaded_options = None
  _globals['_DATASETSERVICE'].methods_by_name['ListUploadFormats']._serialized_options = b'\210\002\001'
  _globals['_DESCRIBEDATASETREQUEST']._serialized_start=261
  _globals['_DESCRIBEDATASETREQUEST']._serialized_end=311
  _globals['_DESCRIBEDATASETRESPONSE']._serialized_start=313
  _globals['_DESCRIBEDATASETRESPONSE']._serialized_end=396
  _globals['_VALIDATEDATASETREQUEST']._serialized_start=398
  _globals['_VALIDATEDATASETREQUEST']._serialized_end=448
  _globals['_VALIDATEDATASETMETADATA']._serialized_start=450
  _globals['_VALIDATEDATASETMETADATA']._serialized_end=559
  _globals['_VALIDATEDATASETRESPONSE']._serialized_start=561
  _globals['_VALIDATEDATASETRESPONSE']._serialized_end=685
  _globals['_DELETEDATASETREQUEST']._serialized_start=687
  _globals['_DELETEDATASETREQUEST']._serialized_end=735
  _globals['_DELETEDATASETRESPONSE']._serialized_start=737
  _globals['_DELETEDATASETRESPONSE']._serialized_end=760
  _globals['_CREATEDATASETREQUEST']._serialized_start=763
  _globals['_CREATEDATASETREQUEST']._serialized_end=1104
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._serialized_start=1059
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._serialized_end=1104
  _globals['_CREATEDATASETRESPONSE']._serialized_start=1106
  _globals['_CREATEDATASETRESPONSE']._serialized_end=1207
  _globals['_UPDATEDATASETREQUEST']._serialized_start=1210
  _globals['_UPDATEDATASETREQUEST']._serialized_end=1467
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._serialized_start=1059
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._serialized_end=1104
  _globals['_UPDATEDATASETRESPONSE']._serialized_start=1469
  _globals['_UPDATEDATASETRESPONSE']._serialized_end=1550
  _globals['_GETUPLOADDRAFTURLREQUEST']._serialized_start=1552
  _globals['_GETUPLOADDRAFTURLREQUEST']._serialized_end=1632
  _globals['_GETUPLOADDRAFTURLRESPONSE']._serialized_start=1634
  _globals['_GETUPLOADDRAFTURLRESPONSE']._serialized_end=1701
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST']._serialized_start=1703
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST']._serialized_end=1806
  _globals['_STARTMULTIPARTUPLOADDRAFTRESPONSE']._serialized_start=1808
  _globals['_STARTMULTIPARTUPLOADDRAFTRESPONSE']._serialized_end=1894
  _globals['_UPLOADEDPARTINFO']._serialized_start=1896
  _globals['_UPLOADEDPARTINFO']._serialized_end=1965
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST']._serialized_start=1968
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST']._serialized_end=2099
  _globals['_FINISHMULTIPARTUPLOADDRAFTRESPONSE']._serialized_start=2101
  _globals['_FINISHMULTIPARTUPLOADDRAFTRESPONSE']._serialized_end=2157
  _globals['_LISTDATASETSREQUEST']._serialized_start=2160
  _globals['_LISTDATASETSREQUEST']._serialized_end=2386
  _globals['_LISTDATASETSRESPONSE']._serialized_start=2388
  _globals['_LISTDATASETSRESPONSE']._serialized_end=2494
  _globals['_LISTUPLOADFORMATSREQUEST']._serialized_start=2496
  _globals['_LISTUPLOADFORMATSREQUEST']._serialized_end=2547
  _globals['_LISTUPLOADFORMATSRESPONSE']._serialized_start=2549
  _globals['_LISTUPLOADFORMATSRESPONSE']._serialized_end=2593
  _globals['_LISTUPLOADSCHEMASREQUEST']._serialized_start=2595
  _globals['_LISTUPLOADSCHEMASREQUEST']._serialized_end=2665
  _globals['_LISTUPLOADSCHEMASRESPONSE']._serialized_start=2667
  _globals['_LISTUPLOADSCHEMASRESPONSE']._serialized_end=2760
  _globals['_LISTTYPESREQUEST']._serialized_start=2762
  _globals['_LISTTYPESREQUEST']._serialized_end=2799
  _globals['_LISTTYPESRESPONSE']._serialized_start=2801
  _globals['_LISTTYPESRESPONSE']._serialized_end=2835
  _globals['_GETDATASETPREVIEWREQUEST']._serialized_start=2837
  _globals['_GETDATASETPREVIEWREQUEST']._serialized_end=2889
  _globals['_GETDATASETPREVIEWRESPONSE']._serialized_start=2891
  _globals['_GETDATASETPREVIEWRESPONSE']._serialized_end=2961
  _globals['_GETDOWNLOADURLSREQUEST']._serialized_start=2963
  _globals['_GETDOWNLOADURLSREQUEST']._serialized_end=3013
  _globals['_GETDOWNLOADURLSRESPONSE']._serialized_start=3015
  _globals['_GETDOWNLOADURLSRESPONSE']._serialized_end=3135
  _globals['_LISTOPERATIONSIDSREQUEST']._serialized_start=3137
  _globals['_LISTOPERATIONSIDSREQUEST']._serialized_end=3183
  _globals['_LISTOPERATIONSIDSRESPONSE']._serialized_start=3186
  _globals['_LISTOPERATIONSIDSRESPONSE']._serialized_end=3395
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._serialized_start=3334
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._serialized_end=3395
  _globals['_DATASETSERVICE']._serialized_start=3398
  _globals['_DATASETSERVICE']._serialized_end=5322
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import style_preset_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__pb2
from yandex.cloud.video.v1 import style_preset_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/video/v1/style_preset_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class StylePresetServiceStub(object):
    """StylePreset management service.
    Provides methods for creating, retrieving, updating, and deleting style presets,
    which define the visual appearance and layout of video players and associated widgets.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.video.v1.StylePresetService/Get',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.GetStylePresetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__pb2.StylePreset.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.StylePresetService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.ListStylePresetsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.ListStylePresetsResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.StylePresetService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.CreateStylePresetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.video.v1.StylePresetService/Update',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.UpdateStylePresetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.video.v1.StylePresetService/Delete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.DeleteStylePresetRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class StylePresetServiceServicer(object):
    """StylePreset management service.
    Provides methods for creating, retrieving, updating, and deleting style presets,
    which define the visual appearance and layout of video players and associated widgets.
    """

    def Get(self, request, context):
        """Retrieves detailed information about a specific style preset by its ID.
        Returns all style preset properties, colors, layout settings, and widget configurations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists all style presets in a specific channel with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a new style preset in the specified channel with the provided visual settings.
        Style presets define the appearance of players, including colors, spacing, borders, and widgets.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing style preset's properties and visual settings.
        Only fields specified in the field_mask will be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a specific style preset by its ID.
        This operation will fail if the style preset is currently in use by any videos, streams, or playlists.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StylePresetServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.GetStylePresetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__pb2.StylePreset.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.ListStylePresetsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.ListStylePresetsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.CreateStylePresetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.UpdateStylePresetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.DeleteStylePresetRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.StylePresetService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.video.v1.StylePresetService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class StylePresetService(object):
    """StylePreset management service.
    Provides methods for creating, retrieving, updating, and deleting style presets,
    which define the visual appearance and layout of video players and associated widgets.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StylePresetService/Get',
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.GetStylePresetRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__pb2.StylePreset.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StylePresetService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.ListStylePresetsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.ListStylePresetsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StylePresetService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.CreateStylePresetRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StylePresetService/Update',
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.UpdateStylePresetRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StylePresetService/Delete',
            yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__service__pb2.DeleteStylePresetRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\x07\x43ronTab\x12\x14\n\x0c\x64\x61y_of_month\x18\x03 \x01(\t\x12\r\n\x05month\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x61y_of_week\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\x06minuteR\x04hour\"\x82\x02\n\x15\x42\x61\x63kupRetentionPolicy\x12\x17\n\tpolicy_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12 \n\ncluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x0bpolicy_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x04\x63ron\x18\x05 \x01(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.CronTab\x12\x17\n\x0fretain_for_days\x18\x06 \x01(\x03\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\tBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_id']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001'
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_name']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_name']._serialized_options = b'\350\3071\001'
  _globals['_CRONTAB']._serialized_start=160
  _globals['_CRONTAB']._serialized_end=253
  _globals['_BACKUPRETENTIONPOLICY']._serialized_start=256
  _globals['_BACKUPRETENTIONPOLICY']._serialized_end=514
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PromptTruncationOptions(google.protobuf.message.Message):
    """Defines the options for truncating thread messages within a prompt."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AutoStrategy(google.protobuf.message.Message):
        """Auto truncation strategy.
        No specific parameters are required for this strategy.
        The system will handle truncation in a way that aims to preserve the most relevant context.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class LastMessagesStrategy(google.protobuf.message.Message):
        """Truncates the prompt by retaining only the last `num_messages` messages in the thread."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NUM_MESSAGES_FIELD_NUMBER: builtins.int
        num_messages: builtins.int
        """The number of most recent messages to retain in the prompt.
        If these messages exceed `max_prompt_tokens`, older messages will be further truncated to fit the limit.
        """
        def __init__(
            self,
            *,
            num_messages: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["num_messages", b"num_messages"]) -> None: ...

    MAX_PROMPT_TOKENS_FIELD_NUMBER: builtins.int
    AUTO_STRATEGY_FIELD_NUMBER: builtins.int
    LAST_MESSAGES_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def max_prompt_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of tokens allowed in the prompt.
        If the prompt exceeds this limit, the thread messages will be truncated.
        Default max_prompt_tokens: 7000
        """

    @property
    def auto_strategy(self) -> global___PromptTruncationOptions.AutoStrategy: ...
    @property
    def last_messages_strategy(self) -> global___PromptTruncationOptions.LastMessagesStrategy:
        """Retains only the last `num_messages` messages in the thread.
        If these messages exceed `max_prompt_tokens`, older messages will be further truncated to fit the limit.
        """

    def __init__(
        self,
        *,
        max_prompt_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        auto_strategy: global___PromptTruncationOptions.AutoStrategy | None = ...,
        last_messages_strategy: global___PromptTruncationOptions.LastMessagesStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["TruncationStrategy", b"TruncationStrategy", "auto_strategy", b"auto_strategy", "last_messages_strategy", b"last_messages_strategy", "max_prompt_tokens", b"max_prompt_tokens"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["TruncationStrategy", b"TruncationStrategy", "auto_strategy", b"auto_strategy", "last_messages_strategy", b"last_messages_strategy", "max_prompt_tokens", b"max_prompt_tokens"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["TruncationStrategy", b"TruncationStrategy"]) -> typing.Literal["auto_strategy", "last_messages_strategy"] | None: ...

global___PromptTruncationOptions = PromptTruncationOptions

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    """Defines the options for completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_TOKENS_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit on the number of tokens used for single completion generation.
        Must be greater than zero. This maximum allowed parameter value may depend on the model being used.
        """

    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Affects creativity and randomness of responses. Should be a double number between 0 (inclusive) and 1 (inclusive).
        Lower values produce more straightforward responses while higher values lead to increased creativity and randomness.
        Default temperature: 0.3
        """

    def __init__(
        self,
        *,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class Tool(google.protobuf.message.Message):
    """Represents a general tool that can be one of several types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    GEN_SEARCH_FIELD_NUMBER: builtins.int
    @property
    def search_index(self) -> global___SearchIndexTool:
        """SearchIndexTool tool that performs search across specified indexes."""

    @property
    def function(self) -> global___FunctionTool:
        """Function tool that can be invoked by the assistant."""

    @property
    def gen_search(self) -> global___GenSearchTool:
        """Performs web retrieval and generative synthesis."""

    def __init__(
        self,
        *,
        search_index: global___SearchIndexTool | None = ...,
        function: global___FunctionTool | None = ...,
        gen_search: global___GenSearchTool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function", "gen_search", b"gen_search", "search_index", b"search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function", "gen_search", b"gen_search", "search_index", b"search_index"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolType", b"ToolType"]) -> typing.Literal["search_index", "function", "gen_search"] | None: ...

global___Tool = Tool

@typing.final
class ToolCall(google.protobuf.message.Message):
    """Represents a call to a tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_CALL_FIELD_NUMBER: builtins.int
    @property
    def function_call(self) -> global___FunctionCall:
        """Represents a call to a function."""

    def __init__(
        self,
        *,
        function_call: global___FunctionCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolCallType", b"ToolCallType"]) -> typing.Literal["function_call"] | None: ...

global___ToolCall = ToolCall

@typing.final
class ToolCallList(google.protobuf.message.Message):
    """Represents a list of tool calls."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_CALLS_FIELD_NUMBER: builtins.int
    @property
    def tool_calls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolCall]:
        """A list of tool calls to be executed."""

    def __init__(
        self,
        *,
        tool_calls: collections.abc.Iterable[global___ToolCall] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_calls", b"tool_calls"]) -> None: ...

global___ToolCallList = ToolCallList

@typing.final
class ToolResult(google.protobuf.message.Message):
    """Represents the result of a tool call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_RESULT_FIELD_NUMBER: builtins.int
    @property
    def function_result(self) -> global___FunctionResult:
        """Represents the result of a function call."""

    def __init__(
        self,
        *,
        function_result: global___FunctionResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolResultType", b"ToolResultType"]) -> typing.Literal["function_result"] | None: ...

global___ToolResult = ToolResult

@typing.final
class ToolResultList(google.protobuf.message.Message):
    """Represents a list of tool results."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def tool_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolResult]:
        """A list of tool results."""

    def __init__(
        self,
        *,
        tool_results: collections.abc.Iterable[global___ToolResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_results", b"tool_results"]) -> None: ...

global___ToolResultList = ToolResultList

@typing.final
class SearchIndexTool(google.protobuf.message.Message):
    """Configures a tool that enables Retrieval-Augmented Generation (RAG) by allowing the assistant to search across a specified search index."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_IDS_FIELD_NUMBER: builtins.int
    MAX_NUM_RESULTS_FIELD_NUMBER: builtins.int
    REPHRASER_OPTIONS_FIELD_NUMBER: builtins.int
    CALL_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def search_index_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of search index IDs that this tool will query. Currently, only a single index ID is supported."""

    @property
    def max_num_results(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of results to return from the search.
        Fewer results may be returned if necessary to fit within the prompt's token limit.
        This ensures that the combined prompt and search results do not exceed the token constraints.
        """

    @property
    def rephraser_options(self) -> global___RephraserOptions:
        """Options for rephrasing user queries.
        Used to rewrite the last user message for search,
        incorporating context from the previous conversation.
        """

    @property
    def call_strategy(self) -> global___CallStrategy:
        """Defines the strategy for triggering search.
        Controls whether search results are always included or returned only when
        the model explicitly calls the tool.
        """

    def __init__(
        self,
        *,
        search_index_ids: collections.abc.Iterable[builtins.str] | None = ...,
        max_num_results: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        rephraser_options: global___RephraserOptions | None = ...,
        call_strategy: global___CallStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["call_strategy", b"call_strategy", "max_num_results", b"max_num_results", "rephraser_options", b"rephraser_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["call_strategy", b"call_strategy", "max_num_results", b"max_num_results", "rephraser_options", b"rephraser_options", "search_index_ids", b"search_index_ids"]) -> None: ...

global___SearchIndexTool = SearchIndexTool

@typing.final
class CallStrategy(google.protobuf.message.Message):
    """Defines when the assistant uses the search tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AlwaysCall(google.protobuf.message.Message):
        """Always includes retrieved search results in the prompt."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class AutoCall(google.protobuf.message.Message):
        """Exposes the tool as a callable function.
        The model decides when to trigger search based on the instruction.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        INSTRUCTION_FIELD_NUMBER: builtins.int
        name: builtins.str
        """The name of the tool as exposed to the model."""
        instruction: builtins.str
        """Required instruction that helps the model decide when to call the tool."""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            instruction: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["instruction", b"instruction", "name", b"name"]) -> None: ...

    ALWAYS_CALL_FIELD_NUMBER: builtins.int
    AUTO_CALL_FIELD_NUMBER: builtins.int
    @property
    def always_call(self) -> global___CallStrategy.AlwaysCall: ...
    @property
    def auto_call(self) -> global___CallStrategy.AutoCall: ...
    def __init__(
        self,
        *,
        always_call: global___CallStrategy.AlwaysCall | None = ...,
        auto_call: global___CallStrategy.AutoCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Strategy", b"Strategy", "always_call", b"always_call", "auto_call", b"auto_call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Strategy", b"Strategy", "always_call", b"always_call", "auto_call", b"auto_call"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Strategy", b"Strategy"]) -> typing.Literal["always_call", "auto_call"] | None: ...

global___CallStrategy = CallStrategy

@typing.final
class FunctionTool(google.protobuf.message.Message):
    """Represents a function tool that can be invoked by the assistant."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function."""
    description: builtins.str
    """A description of the function's purpose or behavior."""
    @property
    def parameters(self) -> google.protobuf.struct_pb2.Struct:
        """A JSON Schema that defines the expected parameters for the function.
        The schema should describe the required fields, their types, and any constraints or default values.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        parameters: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parameters", b"parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "parameters", b"parameters"]) -> None: ...

global___FunctionTool = FunctionTool

@typing.final
class FunctionCall(google.protobuf.message.Message):
    """Represents the invocation of a function with specific arguments."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function being called."""
    @property
    def arguments(self) -> google.protobuf.struct_pb2.Struct:
        """The structured arguments passed to the function.
        These arguments must adhere to the JSON Schema defined in the corresponding function's parameters.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        arguments: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["arguments", b"arguments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "name", b"name"]) -> None: ...

global___FunctionCall = FunctionCall

@typing.final
class FunctionResult(google.protobuf.message.Message):
    """Represents the result of a function call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function that was executed."""
    content: builtins.str
    """The result of the function call, represented as a string.
    This field can be used to store the output of the function.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ContentType", b"ContentType"]) -> typing.Literal["content"] | None: ...

global___FunctionResult = FunctionResult

@typing.final
class RephraserOptions(google.protobuf.message.Message):
    """Options for configuring the rephrasing the last user message for search using context from previous conversation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPHRASER_URI_FIELD_NUMBER: builtins.int
    rephraser_uri: builtins.str
    """The ID of the model used to rephrase the last user message for search."""
    def __init__(
        self,
        *,
        rephraser_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rephraser_uri", b"rephraser_uri"]) -> None: ...

global___RephraserOptions = RephraserOptions

@typing.final
class JsonSchema(google.protobuf.message.Message):
    """Represents the expected structure of the model's response using a JSON Schema."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_FIELD_NUMBER: builtins.int
    @property
    def schema(self) -> google.protobuf.struct_pb2.Struct:
        """The JSON Schema that the model's output must conform to."""

    def __init__(
        self,
        *,
        schema: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["schema", b"schema"]) -> None: ...

global___JsonSchema = JsonSchema

@typing.final
class ResponseFormat(google.protobuf.message.Message):
    """Specifies the format of the model's response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_OBJECT_FIELD_NUMBER: builtins.int
    JSON_SCHEMA_FIELD_NUMBER: builtins.int
    json_object: builtins.bool
    """When set to true, the model will respond with a valid JSON object.
    Be sure to explicitly ask the model for JSON.
    Otherwise, it may generate excessive whitespace and run indefinitely until it reaches the token limit.
    """
    @property
    def json_schema(self) -> global___JsonSchema:
        """Enforces a specific JSON structure for the model's response based on a provided schema."""

    def __init__(
        self,
        *,
        json_object: builtins.bool = ...,
        json_schema: global___JsonSchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ResponseFormat", b"ResponseFormat", "json_object", b"json_object", "json_schema", b"json_schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ResponseFormat", b"ResponseFormat", "json_object", b"json_object", "json_schema", b"json_schema"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ResponseFormat", b"ResponseFormat"]) -> typing.Literal["json_object", "json_schema"] | None: ...

global___ResponseFormat = ResponseFormat

@typing.final
class GenSearchTool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    description: builtins.str
    """description of the purpose"""
    @property
    def options(self) -> global___GenSearchOptions:
        """Scoping and filtering rules for the search query"""

    def __init__(
        self,
        *,
        options: global___GenSearchOptions | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "options", b"options"]) -> None: ...

global___GenSearchTool = GenSearchTool

@typing.final
class GenSearchOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SiteOption(google.protobuf.message.Message):
        """Restricts the search to the specific websites."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SITE_FIELD_NUMBER: builtins.int
        @property
        def site(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            site: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["site", b"site"]) -> None: ...

    @typing.final
    class UrlOption(google.protobuf.message.Message):
        """Restricts the search to the specific pages."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        @property
        def url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            url: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

    @typing.final
    class HostOption(google.protobuf.message.Message):
        """Restricts the search to the specific hosts."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOST_FIELD_NUMBER: builtins.int
        @property
        def host(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            host: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["host", b"host"]) -> None: ...

    @typing.final
    class SearchFilter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _DocFormat:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _DocFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GenSearchOptions.SearchFilter._DocFormat.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            DOC_FORMAT_UNSPECIFIED: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 0
            DOC_FORMAT_PDF: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 1
            DOC_FORMAT_XLS: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 2
            DOC_FORMAT_ODS: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 3
            DOC_FORMAT_RTF: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 4
            DOC_FORMAT_PPT: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 5
            DOC_FORMAT_ODP: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 6
            DOC_FORMAT_SWF: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 7
            DOC_FORMAT_ODT: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 8
            DOC_FORMAT_ODG: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 9
            DOC_FORMAT_DOC: GenSearchOptions.SearchFilter._DocFormat.ValueType  # 10

        class DocFormat(_DocFormat, metaclass=_DocFormatEnumTypeWrapper): ...
        DOC_FORMAT_UNSPECIFIED: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 0
        DOC_FORMAT_PDF: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 1
        DOC_FORMAT_XLS: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 2
        DOC_FORMAT_ODS: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 3
        DOC_FORMAT_RTF: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 4
        DOC_FORMAT_PPT: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 5
        DOC_FORMAT_ODP: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 6
        DOC_FORMAT_SWF: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 7
        DOC_FORMAT_ODT: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 8
        DOC_FORMAT_ODG: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 9
        DOC_FORMAT_DOC: GenSearchOptions.SearchFilter.DocFormat.ValueType  # 10

        DATE_FIELD_NUMBER: builtins.int
        LANG_FIELD_NUMBER: builtins.int
        FORMAT_FIELD_NUMBER: builtins.int
        date: builtins.str
        """Restrict by document date"""
        lang: builtins.str
        """Restrict by document language. Use ISO 639-1 language codes."""
        format: global___GenSearchOptions.SearchFilter.DocFormat.ValueType
        """Restrict by document format."""
        def __init__(
            self,
            *,
            date: builtins.str = ...,
            lang: builtins.str = ...,
            format: global___GenSearchOptions.SearchFilter.DocFormat.ValueType = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["date", b"date", "filter_options", b"filter_options", "format", b"format", "lang", b"lang"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["date", b"date", "filter_options", b"filter_options", "format", b"format", "lang", b"lang"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["filter_options", b"filter_options"]) -> typing.Literal["date", "lang", "format"] | None: ...

    SITE_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ENABLE_NRFM_DOCS_FIELD_NUMBER: builtins.int
    SEARCH_FILTERS_FIELD_NUMBER: builtins.int
    enable_nrfm_docs: builtins.bool
    """Use the documents inaccessible from the front page."""
    @property
    def site(self) -> global___GenSearchOptions.SiteOption: ...
    @property
    def host(self) -> global___GenSearchOptions.HostOption: ...
    @property
    def url(self) -> global___GenSearchOptions.UrlOption: ...
    @property
    def search_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenSearchOptions.SearchFilter]:
        """Restricts the search by date, document formats or language."""

    def __init__(
        self,
        *,
        site: global___GenSearchOptions.SiteOption | None = ...,
        host: global___GenSearchOptions.HostOption | None = ...,
        url: global___GenSearchOptions.UrlOption | None = ...,
        enable_nrfm_docs: builtins.bool = ...,
        search_filters: collections.abc.Iterable[global___GenSearchOptions.SearchFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host", b"host", "site", b"site", "site_options", b"site_options", "url", b"url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enable_nrfm_docs", b"enable_nrfm_docs", "host", b"host", "search_filters", b"search_filters", "site", b"site", "site_options", b"site_options", "url", b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["site_options", b"site_options"]) -> typing.Literal["site", "host", "url"] | None: ...

global___GenSearchOptions = GenSearchOptions
